@@ -15,11 +15,9 @@ factors <- feemparafac(cube, nfac = 3, const = rep('nonneg', 3))
 # must return wrapped multiway::parafac object
 stopifnot(inherits(factors, 'feemparafac'), inherits(factors, 'parafac'))
 
-# must be able to produce plots
-plot(fitted(factors))
-plot(resid(factors))
-plot(factors, 'image')
-plot(factors, 'lines')
+# need these methods
+fitted(factors)
+resid(factors)
 
 # fitted / residuals must be of the same kind as original cube
 stopifnot(is.null(attr.all.equal(cube, fitted(factors))))
