@@ -12,10 +12,6 @@ cube <- feemscale(
 # must make sense for only one number of factors / one split
 (sh <- feemsplithalf(cube, 2, random = 1))
 stopifnot(inherits(sh, 'feemsplithalf'))
-plot(sh, 'tcc')
-plot(sh, 'factors')
 
 # must handle non-even numbers of samples
 (sh <- feemsplithalf(cube[,,1:11], 2:3, splits = 4, const = rep('nonneg', 3)))
-plot(sh)
-plot(sh, 'f')
